from setuptools import setup, find_packages

setup(name='gk248861',
      version='1.1',
      author='Grzegorz Kuchta',
      author_email='248861@student.pwr.edu.pl',
      packages=find_packages(),
      )
